==> wls-plugin-1.3.2.1-sources.jar: com/xebialabs/deployit/plugin/wls/mapper/WlsSharedLibraryJarToWlsServerMapper.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.mapper;

import java.util.LinkedList;
import java.util.List;

import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.ci.Deployment;
import com.xebialabs.deployit.mapper.Mapper;
import com.xebialabs.deployit.mapper.Pair;
import com.xebialabs.deployit.plugin.wls.ci.WlsSharedLibraryJar;
import com.xebialabs.deployit.plugin.wls.ci.WlsSharedLibraryJarMapping;
import com.xebialabs.deployit.plugin.wls.ci.WlsArtifactMapping;
import com.xebialabs.deployit.plugin.wls.ci.WlsServer;
import com.xebialabs.deployit.plugin.wls.step.StartApplicationStep;
import com.xebialabs.deployit.plugin.wls.step.StopApplicationStep;
import com.xebialabs.deployit.plugin.wls.step.WlsUndeployArtifactStep;


public class WlsSharedLibraryJarToWlsServerMapper extends Mapper<WlsSharedLibraryJar, WlsSharedLibraryJarMapping, WlsServer> {
    public WlsSharedLibraryJarToWlsServerMapper(Change<Deployment> change) {
        super(change);
    }

    public void generateUndeploySteps(List<Step> steps) {
        for (WlsSharedLibraryJarMapping m : getDeletedMappings()) {
            steps.add(new StopApplicationStep((WlsServer) m.getTarget(), m.getSource()));
            steps.add(new WlsUndeployArtifactStep((WlsServer) m.getTarget(), m.getSource()));
        }
        for (Pair<WlsSharedLibraryJarMapping, WlsSharedLibraryJarMapping> mPair : getModifiedMappings()) {
            steps.add(new StopApplicationStep((WlsServer) mPair.getFirst().getTarget(), mPair.getFirst().getSource()));
            steps.add(new WlsUndeployArtifactStep((WlsServer) mPair.getFirst().getTarget(), mPair.getFirst().getSource()));
        }
    }

    public void generateDeploySteps(List<Step> steps) {
        List<WlsArtifactMapping> wlsArtefactMappings = new LinkedList<WlsArtifactMapping>();

        for (Pair<WlsSharedLibraryJarMapping, WlsSharedLibraryJarMapping> mPair : getModifiedMappings()) {
            wlsArtefactMappings.add(mPair.getSecond());
        }

        for (WlsSharedLibraryJarMapping mapping : getAddedMappings()) {
            wlsArtefactMappings.add(mapping);
        }

        steps.addAll(new WlsStageModeMapperHelper().generateDeploySteps(wlsArtefactMappings));
    }

    public void generateStartSteps(List<Step> steps) {
        for (Pair<WlsSharedLibraryJarMapping, WlsSharedLibraryJarMapping> mPair : getModifiedMappings()) {
            steps.add(new StartApplicationStep((WlsServer) mPair.getSecond().getTarget(), mPair.getSecond().getSource()));
        }
        for (WlsSharedLibraryJarMapping m : getAddedMappings()) {
            steps.add(new StartApplicationStep((WlsServer) m.getTarget(), m.getSource()));
        }
    }

}

==> wls-plugin-1.4-sources.jar: com/xebialabs/deployit/plugin/wls/mapper/WlsSharedLibraryJarToWlsServerMapper.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.mapper;

import com.google.common.collect.Lists;
import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.ci.Deployment;
import com.xebialabs.deployit.mapper.Mapper;
import com.xebialabs.deployit.plugin.wls.ci.WlsArtifactMapping;
import com.xebialabs.deployit.plugin.wls.ci.WlsServer;
import com.xebialabs.deployit.plugin.wls.ci.WlsSharedLibraryJar;
import com.xebialabs.deployit.plugin.wls.ci.WlsSharedLibraryJarMapping;

import java.util.List;


public class WlsSharedLibraryJarToWlsServerMapper extends Mapper<WlsSharedLibraryJar, WlsSharedLibraryJarMapping, WlsServer> {
	public WlsSharedLibraryJarToWlsServerMapper(Change<Deployment> change) {
		super(change);
	}

	public void generateUndeploySteps(List<Step> steps) {
		List<WlsSharedLibraryJarMapping> mappings = Lists.newArrayList(getDeletedMappings());
		mappings.addAll(Lists.transform(getModifiedMappings(), FIRST_MAPPING));
		steps.addAll(new WlsArtifactDeployer().generateUndeploysSteps(mappings));
	}

	public void generateDeploySteps(List<Step> steps) {
		List<WlsArtifactMapping> mappings = Lists.newArrayList();
		mappings.addAll(Lists.transform(getModifiedMappings(), SECOND_MAPPING));
		mappings.addAll(getAddedMappings());
		steps.addAll(new WlsArtifactDeployer().generateDeploySteps(mappings));
	}

	public void generateStartSteps(List<Step> steps) {
		List<WlsSharedLibraryJarMapping> mappings = Lists.newArrayList();
		mappings.addAll(Lists.transform(getModifiedMappings(), SECOND_MAPPING));
		mappings.addAll(getAddedMappings());
		steps.addAll(new WlsArtifactDeployer().generateStartSteps(mappings));
	}

}
